@@ -3,16 +3,11 @@ package InfoSys::FreeDB;
 use 5.006;
 use strict;
 use warnings;
-use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 use Sys::Hostname;
 
 # Package version
-our ($VERSION) = '$Revision: 0.12 $' =~ /\$Revision:\s+([^\s]+)/;
-
-1;
-
-__END__
+our ($VERSION) = '$Revision: 0.9 $' =~ /\$Revision:\s+([^\s]+)/;
 
 =head1 NAME
 
@@ -322,3 +317,4 @@ sub create_connection {
     return($conn);
 }
 
+1;
