@@ -4,7 +4,6 @@ use 5.006;
 use base qw( Exporter );
 use strict;
 use warnings;
-use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 require Exporter;
 
@@ -27,7 +26,7 @@ our %EXPORT_TAGS = (
 );
 
 # Package version
-our ($VERSION) = '$Revision: 0.12 $' =~ /\$Revision:\s+([^\s]+)/;
+our ($VERSION) = '$Revision: 0.9 $' =~ /\$Revision:\s+([^\s]+)/;
 
 # Exporter variable
 our @EXPORT = qw(
@@ -39,10 +38,6 @@ our @EXPORT_OK = qw(
     $FINAL_EOL_RX
 );
 
-1;
-
-__END__
-
 =head1 NAME
 
 InfoSys::FreeDB::Connection - FreeDB abstract connection
@@ -875,3 +870,4 @@ sub write {
     throw Error::Simple("ERROR: InfoSys::FreeDB::Connection::write, call this method in a subclass that has implemented it.");
 }
 
+1;
