@@ -4,7 +4,6 @@ use 5.006;
 use base qw( InfoSys::FreeDB::Connection );
 use strict;
 use warnings;
-use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 use IO::Socket::INET;
 use InfoSys::FreeDB::Connection qw(:line_parse);
@@ -27,11 +26,7 @@ our %ALLOW_VALUE = (
 );
 
 # Package version
-our ($VERSION) = '$Revision: 0.12 $' =~ /\$Revision:\s+([^\s]+)/;
-
-1;
-
-__END__
+our ($VERSION) = '$Revision: 0.9 $' =~ /\$Revision:\s+([^\s]+)/;
 
 =head1 NAME
 
@@ -756,3 +751,4 @@ sub write {
     ) );
 }
 
+1;
