@@ -3,7 +3,6 @@ package InfoSys::FreeDB::Entry;
 use 5.006;
 use strict;
 use warnings;
-use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 use IO::File;
 
@@ -19,7 +18,7 @@ our $DID_RX = '^\s*DISCID\s*=\s*(\S+)\s*$';
 
 our $DL_ERR = '# Disc length: <length> seconds';
 
-our $DL_RX = '^\s*#\s*Disc\s+length\s*:\s*(\d+)\s+sec[ond]{0,3}s\s*$';
+our $DL_RX = '^\s*#\s*Disc\s+length\s*:\s*(\d+)\s+seconds\s*$';
 
 our $DTITLE_RX = '^\s*DTITLE\s*=(.*)$';
 
@@ -69,11 +68,7 @@ our %ALLOW_VALUE = (
 );
 
 # Package version
-our ($VERSION) = '$Revision: 0.12 $' =~ /\$Revision:\s+([^\s]+)/;
-
-1;
-
-__END__
+our ($VERSION) = '$Revision: 0.9 $' =~ /\$Revision:\s+([^\s]+)/;
 
 =head1 NAME
 
@@ -434,7 +429,7 @@ None known (yet.)
 =head1 HISTORY
 
 First development: September 2003
-Last update: November 2003
+Last update: October 2003
 
 =head1 AUTHOR
 
@@ -1196,9 +1191,7 @@ sub write_array_ref {
     push(@array, "#");
 
     # DISCID
-    $self->get_discid() ||
-        $self->mk_discid();
-    push( @array, "DISCID=" . ( $self->get_discid() ) );
+    push( @array, "DISCID=" . ($self->get_discid() || '') );
 
     # DTITLE (Artist / Title)
     push( @array, &_str2db_lines( 'DTITLE=',
@@ -1266,3 +1259,4 @@ sub write_fn {
     $self->write_fh($fh);
 }
 
+1;
