@@ -3,15 +3,10 @@ package InfoSys::FreeDB::Entry::Track;
 use 5.006;
 use strict;
 use warnings;
-use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 
 # Package version
-our ($VERSION) = '$Revision: 0.12 $' =~ /\$Revision:\s+([^\s]+)/;
-
-1;
-
-__END__
+our ($VERSION) = '$Revision: 0.9 $' =~ /\$Revision:\s+([^\s]+)/;
 
 =head1 NAME
 
@@ -268,3 +263,4 @@ sub set_title {
 sub write_fh {
 }
 
+1;
