@@ -3,15 +3,10 @@ package InfoSys::FreeDB::Match;
 use 5.006;
 use strict;
 use warnings;
-use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 
 # Package version
-our ($VERSION) = '$Revision: 0.12 $' =~ /\$Revision:\s+([^\s]+)/;
-
-1;
-
-__END__
+our ($VERSION) = '$Revision: 0.9 $' =~ /\$Revision:\s+([^\s]+)/;
 
 =head1 NAME
 
@@ -259,3 +254,4 @@ sub set_dtitle {
     $self->{InfoSys_FreeDB_Match}{dtitle} = $val;
 }
 
+1;
