@@ -4,16 +4,11 @@ use 5.006;
 use base qw( InfoSys::FreeDB::Response );
 use strict;
 use warnings;
-use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 use InfoSys::FreeDB::Response qw(:line_parse);
 
 # Package version
-our ($VERSION) = '$Revision: 0.12 $' =~ /\$Revision:\s+([^\s]+)/;
-
-1;
-
-__END__
+our ($VERSION) = '$Revision: 0.9 $' =~ /\$Revision:\s+([^\s]+)/;
 
 =head1 NAME
 
@@ -271,3 +266,4 @@ sub set_discid {
     $self->{InfoSys_FreeDB_Response_DiscId}{discid} = $val;
 }
 
+1;
