@@ -4,15 +4,10 @@ use 5.006;
 use base qw( InfoSys::FreeDB::Response );
 use strict;
 use warnings;
-use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 
 # Package version
-our ($VERSION) = '$Revision: 0.12 $' =~ /\$Revision:\s+([^\s]+)/;
-
-1;
-
-__END__
+our ($VERSION) = '$Revision: 0.9 $' =~ /\$Revision:\s+([^\s]+)/;
 
 =head1 NAME
 
@@ -378,3 +373,4 @@ sub unshift_category {
     unshift( @{ $self->{InfoSys_FreeDB_Response_LsCat}{category} }, @_ );
 }
 
+1;
