@@ -4,7 +4,6 @@ use 5.006;
 use base qw( InfoSys::FreeDB::Response );
 use strict;
 use warnings;
-use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 use InfoSys::FreeDB::Response qw(:line_parse);
 
@@ -14,11 +13,7 @@ our %DEFAULT_VALUE = (
 );
 
 # Package version
-our ($VERSION) = '$Revision: 0.12 $' =~ /\$Revision:\s+([^\s]+)/;
-
-1;
-
-__END__
+our ($VERSION) = '$Revision: 0.9 $' =~ /\$Revision:\s+([^\s]+)/;
 
 =head1 NAME
 
@@ -305,3 +300,4 @@ sub set_message_text {
     $self->{InfoSys_FreeDB_Response_Motd}{message_text} = $val;
 }
 
+1;
