@@ -4,7 +4,6 @@ use 5.006;
 use base qw( InfoSys::FreeDB::Response );
 use strict;
 use warnings;
-use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 
 # Used by _value_is_allowed
@@ -25,11 +24,7 @@ our %ALLOW_VALUE = (
 );
 
 # Package version
-our ($VERSION) = '$Revision: 0.12 $' =~ /\$Revision:\s+([^\s]+)/;
-
-1;
-
-__END__
+our ($VERSION) = '$Revision: 0.9 $' =~ /\$Revision:\s+([^\s]+)/;
 
 =head1 NAME
 
@@ -536,3 +531,4 @@ sub unshift_site {
     unshift( @{ $self->{InfoSys_FreeDB_Response_Sites}{site} }, @_ );
 }
 
+1;
