@@ -4,7 +4,6 @@ use 5.006;
 use base qw( InfoSys::FreeDB::Response );
 use strict;
 use warnings;
-use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 
 our $STAT_DB_ENTRIES_RX = '^\s*database\s+entries\s*:\s*(\S+)';
@@ -28,11 +27,7 @@ our $STAT_USERS_CUR_RX = '^\s*current\s+users\s*:\s*(\S+)';
 our $STAT_USERS_MAX_RX = '^\s*max\s+users\s*:\s*(\S+)';
 
 # Package version
-our ($VERSION) = '$Revision: 0.12 $' =~ /\$Revision:\s+([^\s]+)/;
-
-1;
-
-__END__
+our ($VERSION) = '$Revision: 0.9 $' =~ /\$Revision:\s+([^\s]+)/;
 
 =head1 NAME
 
@@ -632,3 +627,4 @@ sub set_users_max {
     $self->{InfoSys_FreeDB_Response_Stat}{users_max} = $val;
 }
 
+1;
