@@ -3,7 +3,6 @@ package InfoSys::FreeDB::Site;
 use 5.006;
 use strict;
 use warnings;
-use AutoLoader qw(AUTOLOAD);
 use Error qw(:try);
 
 # Used by _initialize
@@ -12,11 +11,7 @@ our %DEFAULT_VALUE = (
 );
 
 # Package version
-our ($VERSION) = '$Revision: 0.12 $' =~ /\$Revision:\s+([^\s]+)/;
-
-1;
-
-__END__
+our ($VERSION) = '$Revision: 0.9 $' =~ /\$Revision:\s+([^\s]+)/;
 
 =head1 NAME
 
@@ -393,3 +388,4 @@ sub set_site {
     $self->{InfoSys_FreeDB_Site}{site} = $val;
 }
 
+1;
